@@ -17,7 +17,7 @@
  *          Matthew Saltzman, Clemson University                             *
  *                                                                           * 
  *                                                                           *
- * Copyright (C) 2001-2007, Lehigh University, Yan Xu, and Ted Ralphs.       *
+ * Copyright (C) 2001-2010, Lehigh University, Yan Xu, and Ted Ralphs.       *
  * All Rights Reserved.                                                      *
  *===========================================================================*/
 
@@ -64,6 +64,7 @@ class BlisVariable;
 
 //#############################################################################
 
+/* Declare a BLIS model */
 class BlisModel : public BcpsModel {
 
 protected:
@@ -295,12 +296,18 @@ protected:
     /** Integer tolerance. */
     double integerTol_;
 
-    /** Relative optimal gap. */
+    /** Input relative optimal gap. */
     double optimalRelGap_;
 
-    /** Absolute optimal gap. */
+    /** Input absolute optimal gap. */
     double optimalAbsGap_;
 
+    /** Current relative optimal gap. */
+    double currRelGap_;
+
+    /** Current absolute optimal gap. */
+    double currAbsGap_;
+
     /** If use heuristics. */
     BlisHeurStrategy heurStrategy_;
     
@@ -825,6 +832,9 @@ protected:
     /** Node log. */
     virtual void nodeLog(AlpsTreeNode *node, bool force);
 
+    /** Return true, if all nodes can be fathomed.*/
+    virtual bool fathomAllNodes();
+
     //------------------------------------------------------
     // PARALLEL
     //------------------------------------------------------
